[SCM] Samba Shared Repository - branch master updated

David Disseldorp ddiss at samba.org
Fri Sep 28 11:29:02 MDT 2012


The branch, master has been updated
       via  0d7a2af vfs: check full_audit enum->str mapping on startup
       via  e8e91fb vfs: add missing pwrite ops to full_audit
      from  b9ca792 WHATSNEW: Add changed parameters.

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 0d7a2af9084c376ad4f664389bb8a59dd6887ab7
Author: David Disseldorp <ddiss at samba.org>
Date:   Thu Sep 27 12:34:53 2012 +0200

    vfs: check full_audit enum->str mapping on startup
    
    Signed-off-by: Jim McDonough <jmcd at samba.org>
    
    Autobuild-User(master): David Disseldorp <ddiss at samba.org>
    Autobuild-Date(master): Fri Sep 28 19:28:49 CEST 2012 on sn-devel-104

commit e8e91fbbab16c7bcaa9665839d86c7d169e89fff
Author: David Disseldorp <ddiss at samba.org>
Date:   Thu Sep 27 11:50:22 2012 +0200

    vfs: add missing pwrite ops to full_audit
    
    The op enum is used by audit_opname() as an index into the vfs_op_names
    array, so any decrepencies cause bogus audit log entries.
    
    Signed-off-by: Jim McDonough <jmcd at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 source3/modules/vfs_full_audit.c |    9 ++++++---
 1 files changed, 6 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/modules/vfs_full_audit.c b/source3/modules/vfs_full_audit.c
index 1a481ab..6050c55 100644
--- a/source3/modules/vfs_full_audit.c
+++ b/source3/modules/vfs_full_audit.c
@@ -203,7 +203,7 @@ typedef enum _vfs_op_type {
 	SMB_VFS_OP_LAST
 } vfs_op_type;
 
 /* The following array *must* be in the same order as defined in vfs.h */
 
 static struct {
 	vfs_op_type type;
@@ -236,6 +236,8 @@ static struct {
 	{ SMB_VFS_OP_PREAD_RECV,	"pread_recv" },
 	{ SMB_VFS_OP_WRITE,	"write" },
 	{ SMB_VFS_OP_PWRITE,	"pwrite" },
+	{ SMB_VFS_OP_PWRITE_SEND,	"pwrite_send" },
+	{ SMB_VFS_OP_PWRITE_RECV,	"pwrite_recv" },
 	{ SMB_VFS_OP_LSEEK,	"lseek" },
 	{ SMB_VFS_OP_SENDFILE,	"sendfile" },
 	{ SMB_VFS_OP_RECVFILE,  "recvfile" },
@@ -442,9 +444,10 @@ static struct bitmap *init_bitmap(TALLOC_CTX *mem_ctx, const char **ops)
 		}
 
 		for (i=0; i<SMB_VFS_OP_LAST; i++) {
-			if (vfs_op_names[i].name == NULL) {
+			if ((vfs_op_names[i].name == NULL)
+			 || (vfs_op_names[i].type != i)) {
 				smb_panic("vfs_full_audit.c: name table not "
-					  "in sync with vfs.h\n");
+					  "in sync with vfs_op_type enums\n");
 			}
 			if (strequal(op, vfs_op_names[i].name)) {
 				if (neg) {
@@ -203,7 +203,7 @@ typedef enum _vfs_op_type {
 } vfs_op_type;
 
-/* The following array *must* be in the same order as defined in vfs.h */
+/* The following array *must* be in the same order as defined in vfs_op_type */
 
 static struct {


-- 
Samba Shared Repository


More information about the samba-cvs mailing list